summaryrefslogtreecommitdiff
path: root/gtk2_ardour/audio_clock.cc
diff options
context:
space:
mode:
authorPaul Davis <paul@linuxaudiosystems.com>2008-02-05 15:34:13 +0000
committerPaul Davis <paul@linuxaudiosystems.com>2008-02-05 15:34:13 +0000
commit4a0f94395d130a55107249a74f1adf4b758afd76 (patch)
tree884fb586d4bd4b869498313eee299bd0c0feabe9 /gtk2_ardour/audio_clock.cc
parenta38cba7f9721db5c2421326cc4d701e9f09345ea (diff)
adjusting region fade in/out lengths makes the fade in/out active; new font sizes; new font generation code in gtk2_ardour/SConscript; move mixer strip/group pane over to the RHS to match the editor; clean up ardour-sae-de.bindings.in; fix glue-to-music-time menu item (was always active)
git-svn-id: svn://localhost/ardour2/branches/2.0-ongoing@3010 d708f5d6-7413-0410-9779-e7cbd77b26cf
Diffstat (limited to 'gtk2_ardour/audio_clock.cc')
-rw-r--r--gtk2_ardour/audio_clock.cc7
1 files changed, 4 insertions, 3 deletions
diff --git a/gtk2_ardour/audio_clock.cc b/gtk2_ardour/audio_clock.cc
index 33f522f234..b42a55ad52 100644
--- a/gtk2_ardour/audio_clock.cc
+++ b/gtk2_ardour/audio_clock.cc
@@ -855,11 +855,12 @@ AudioClock::field_key_release_event (GdkEventKey *ev, Field field)
case Bars:
case Beats:
case Ticks:
- // Bars or beats should never be 0
- if (atoi(bars_label.get_text()) == 0) {
+ // Bars should never be, unless this clock is for a duration
+ if (atoi(bars_label.get_text()) == 0 && !is_duration) {
bars_label.set_text("001");
}
- if (atoi(beats_label.get_text()) == 0) {
+ // beats should never be 0, unless this clock is for a duration
+ if (atoi(beats_label.get_text()) == 0 && !is_duration) {
beats_label.set_text("01");
}
break;